/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'list', 'el', {
	bulletedlist: 'Εισαγωγή/Απομάκρυνση Λίστας Κουκκίδων',
	numberedlist: 'Εισαγωγή/Απομάκρυνση Αριθμημένης Λίστας'
} );
