/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'uk', {
	options: 'Опції',
	title: 'Оберіть спеціальний символ',
	toolbar: 'Спеціальний символ'
} );
