/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'fakeobjects', 'ug', {
	anchor: 'لەڭگەرلىك نۇقتا',
	flash: 'Flash جانلاندۇرۇم',
	hiddenfield: 'يوشۇرۇن دائىرە',
	iframe: 'IFrame',
	unknown: 'يوچۇن نەڭ'
} );
