/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'about', 'tr', {
	copy: 'Copyright &copy; $1. Tüm hakları saklıdır.',
	dlgTitle: 'CKEditor Hakkında',
	moreInfo: 'Lisanslama hakkında daha fazla bilgi almak için lütfen sitemizi ziyaret edin:'
} );
