/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'pl', {
	options: 'Opcje znaków specjalnych',
	title: 'Wybierz znak specjalny',
	toolbar: 'Wstaw znak specjalny'
} );
