/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'about', 'lt', {
	copy: 'Copyright &copy; $1. Visos teiss saugomos.',
	dlgTitle: 'Apie CKEditor 4',
	moreInfo: 'Dėl licencijavimo apsilankykite mūsų svetainėje:'
} );
