/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colordialog', 'nl', {
	clear: 'Wissen',
	highlight: 'Actief',
	options: 'Kleuropties',
	selected: 'Geselecteerde kleur',
	title: 'Selecteer kleur'
} );
